@@ -13,6 +13,7 @@
 ##############################################################################
 """Attribute Annotations implementation"""
 import logging
+from collections import MutableMapping as DictMixin
 
 try:
     from BTrees.OOBTree import OOBTree as _STORAGE
@@ -24,7 +25,6 @@ except ImportError: # pragma: no cover
 from zope import component, interface
 from zope.annotation import interfaces
 
-from collections import MutableMapping as DictMixin
 
 _EMPTY_STORAGE = _STORAGE()
 
@@ -37,9 +37,21 @@ class AttributeAnnotations(DictMixin):
     `IAttributeAnnotatable` object.
     """
 
+    # Yes, there's a lot of repetition of the `getattr` call,
+    # but that turns out to be the most efficient for the ways
+    # instances are typically used without sacrificing any semantics.
+    # See https://github.com/zopefoundation/zope.annotation/issues/8
+    # for a discussion of alternatives (which included functools.partial,
+    # a closure, capturing the annotations in __init__, and versions
+    # with getattr and exceptions).
+
     def __init__(self, obj, context=None):
         self.obj = obj
 
+    @property
+    def __parent__(self):
+        return self.obj
+
     def __bool__(self):
         return bool(getattr(self.obj, '__annotations__', 0))
 
